summaryrefslogtreecommitdiff
path: root/sigrokdecode.h
diff options
context:
space:
mode:
Diffstat (limited to 'sigrokdecode.h')
-rw-r--r--sigrokdecode.h3
1 files changed, 2 insertions, 1 deletions
diff --git a/sigrokdecode.h b/sigrokdecode.h
index fde9208..9f79252 100644
--- a/sigrokdecode.h
+++ b/sigrokdecode.h
@@ -91,7 +91,8 @@ struct srd_decoder {
/** TODO */
PyObject *py_mod;
- /** Python function that performs the decoding */
+ /** Python object that performs the decoding */
+ PyObject *py_decobj;
PyObject *py_instance;
};